==> basic256_0.9.6.59.orig.tar.gz: MainWindow.h <==
/** Copyright (C) 2006, Ian Paul Larsen.
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
 **  the Free Software Foundation; either version 2 of the License, or
 **  (at your option) any later version.
 **
 **  This program is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License along
 **  with this program; if not, write to the Free Software Foundation, Inc.,
 **  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 **/


#ifndef __MAINWINDOW_H
#define __MAINWINDOW_H

#include <QMainWindow>
#include <QGridLayout>
#include <QAction>
#include <QMessageBox>

#include "BasicWidget.h"
#include "BasicOutput.h"
#include "BasicEdit.h"
#include "BasicGraph.h"
#include "VariableWin.h"
#include "DocumentationWin.h"
#include "PreferencesWin.h"
#include "EditSyntaxHighlighter.h"
#include "Settings.h"


class MainWindow : public QMainWindow
{
  	Q_OBJECT;
public:
  	MainWindow(QWidget * parent = 0, Qt::WindowFlags f = 0);
	~MainWindow();
	void closeEvent(QCloseEvent *);
	QAction * runact;
	QAction * debugact;
	QAction * stepact;
	QAction * stopact;
  	BasicEdit * editor;
  	BasicOutput * output;
	BasicGraph * goutput;
	VariableWin * vardock;
	DocumentationWin * docdock;
	EditSyntaxHighlighter * editsyntax;

	QString localecode;

private:
	QAction *recentact[SETTINGSGROUPHISTN]; 

private slots:
	void onlineHelp();
	void updateRecent();
	void about();
};

#endif

==> basic256_0.9.6.66.orig.tar.gz: MainWindow.h <==
/** Copyright (C) 2006, Ian Paul Larsen.
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
 **  the Free Software Foundation; either version 2 of the License, or
 **  (at your option) any later version.
 **
 **  This program is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License along
 **  with this program; if not, write to the Free Software Foundation, Inc.,
 **  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 **/


#ifndef __MAINWINDOW_H
#define __MAINWINDOW_H

#include <QMainWindow>
#include <QGridLayout>
#include <QAction>
#include <QMessageBox>

#include "BasicWidget.h"
#include "BasicOutput.h"
#include "BasicEdit.h"
#include "BasicGraph.h"
#include "VariableWin.h"
#include "DocumentationWin.h"
#include "PreferencesWin.h"
#include "EditSyntaxHighlighter.h"
#include "Settings.h"


class MainWindow : public QMainWindow
{
  	Q_OBJECT;
public:
  	MainWindow(QWidget * parent = 0, Qt::WindowFlags f = 0);
	~MainWindow();
	void closeEvent(QCloseEvent *);
	QAction * runact;
	QAction * debugact;
	QAction * stepact;
	QAction * stopact;
	QAction *editWinVisibleAct;
	QAction *textWinVisibleAct;
	QAction *graphWinVisibleAct;
  	BasicEdit * editor;
  	BasicOutput * output;
	BasicGraph * goutput;
	BasicWidget * editorwgt;
	BasicWidget * outputwgt;
	BasicWidget * goutputwgt;
	VariableWin * vardock;
	DocumentationWin * docdock;
	EditSyntaxHighlighter * editsyntax;

	QString localecode;

private:
	QAction *recentact[SETTINGSGROUPHISTN]; 
	// void pointer to the run controller
	// can't specify type because of circular reference
	void *rcvoidpointer;		

private slots:
	void onlineHelp();
	void updateRecent();
	void about();
};

#endif
